# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import (
    delivery_shipper_delivery_method_pb2 as v1_dot_rules_dot_delivery__shipper__delivery__method__pb2,
)


class DeliveryShipperDeliveryMethodServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DeliveryShipperDeliveryMethodCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodService/DeliveryShipperDeliveryMethodCreate",
            request_serializer=v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodCreateResponse.FromString,
        )
        self.DeliveryShipperDeliveryMethodRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodService/DeliveryShipperDeliveryMethodRead",
            request_serializer=v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodReadResponse.FromString,
        )
        self.DeliveryShipperDeliveryMethodUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodService/DeliveryShipperDeliveryMethodUpdate",
            request_serializer=v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodUpdateResponse.FromString,
        )
        self.DeliveryShipperDeliveryMethodDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodService/DeliveryShipperDeliveryMethodDelete",
            request_serializer=v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodDeleteResponse.FromString,
        )


class DeliveryShipperDeliveryMethodServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DeliveryShipperDeliveryMethodCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryShipperDeliveryMethodRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryShipperDeliveryMethodUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryShipperDeliveryMethodDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_DeliveryShipperDeliveryMethodServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "DeliveryShipperDeliveryMethodCreate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryShipperDeliveryMethodCreate,
            request_deserializer=v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodCreateResponse.SerializeToString,
        ),
        "DeliveryShipperDeliveryMethodRead": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryShipperDeliveryMethodRead,
            request_deserializer=v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodReadResponse.SerializeToString,
        ),
        "DeliveryShipperDeliveryMethodUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryShipperDeliveryMethodUpdate,
            request_deserializer=v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodUpdateResponse.SerializeToString,
        ),
        "DeliveryShipperDeliveryMethodDelete": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryShipperDeliveryMethodDelete,
            request_deserializer=v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodService",
        rpc_method_handlers,
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class DeliveryShipperDeliveryMethodService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DeliveryShipperDeliveryMethodCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodService/DeliveryShipperDeliveryMethodCreate",
            v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodCreateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryShipperDeliveryMethodRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodService/DeliveryShipperDeliveryMethodRead",
            v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodReadRequest.SerializeToString,
            v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryShipperDeliveryMethodUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodService/DeliveryShipperDeliveryMethodUpdate",
            v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodUpdateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryShipperDeliveryMethodDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodService/DeliveryShipperDeliveryMethodDelete",
            v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodDeleteRequest.SerializeToString,
            v1_dot_rules_dot_delivery__shipper__delivery__method__pb2.DeliveryShipperDeliveryMethodDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
